##  Overview
S-user administrators control your organization's access to SAP systems. They create and delete S-user IDs, assign permissions, and help colleagues use tools such as SAP for Me.
When your organization becomes an SAP customer, SAP creates the first S-user ID. This ID has the highest authorization level and acts as the super administrator or cloud administrator. This account can then create other administrators roles, for example, the organization's S-user administrator for user management and access.
This guide describes how set up your organization’s first S-user administrator to start managing access to SAP for Me.
**Note**
After this, SAP does not create or manage more S-user IDs for your organization. For security reasons, your S-user administrators must manage all additional user accounts.
